@@ -5,4 +5,6 @@ PermissionsX - Authorization for Django.
 :license:   BSD, see LICENSE for more details.
 
 """
-from permissionsx.contrib.django import register
+from __future__ import absolute_import
+
+from permissionsx.contrib.django.templatetags import register  # noqa
