@@ -5,19 +5,20 @@ PermissionsX - Authorization for Django.
 :license:   BSD, see LICENSE for more details.
 
 """
-from django.contrib.auth.models import User
+from __future__ import absolute_import
+
 from django.test import (
-    TestCase,
     RequestFactory,
+    TestCase,
 )
-from django.test.client import Client
+from django.contrib.auth import logout
+from django.contrib.auth.models import User
 from django.contrib.sessions.backends.db import SessionStore
 from django.contrib.sessions.middleware import SessionMiddleware
-from django.contrib.auth import logout
+from django.test.client import Client
 
-from permissionsx.tests.models import Profile
-from permissionsx.models import Permissions
 from permissionsx import settings
+from permissionsx.tests.models import Profile
 
 
 DEFAULT_PASSWORD = 'password'
@@ -54,12 +55,6 @@ class UtilityTestCase(TestCase):
         logout(request)
         return request
 
-    def permissions_for_request(self, permissions, request):
-        if isinstance(permissions, Permissions):
-            return permissions.check_permissions(request)
-        else:
-            return permissions().check_permissions(request)
-
 
 # NOTE: SettingsOverride comes from `https://github.com/divio/django-cms/`.
 
